@@ -129,15 +129,15 @@ config* parseOptions (config* conf, int argc, char **argv) {
 					conf->longtable = 1;
 					break;
 			case 'b': /* csv block delimiter */
-					if(optarg[0] == 'q')
+					if (optarg[0] == 'q')
 						conf->block = '\'';
-					else if(optarg[0] == 'd')
+					else if (optarg[0] == 'd')
 						conf->block = '"';
-					else if(optarg[0] == 'n')
+					else if (optarg[0] == 'n')
 						conf->block = 0; /* no block delimiter */
 					break;
 			case 'l': /* number of lines per TeX tabulars */
-					if(isdigit(optarg[0])) {
+					if (isdigit(optarg[0])) {
 						conf->lines = atoi(optarg);
 					} else {
 						fprintf(stderr,
@@ -160,19 +160,19 @@ config* parseOptions (config* conf, int argc, char **argv) {
 					conf->pos = optarg[0]; /* position char in cell */
 					break;
 			case 's': /* csv block separator */
-					if(optarg[0] == 'c')
+					if (optarg[0] == 'c')
 						conf->sep = ',';
-					else if(optarg[0] == 's')
+					else if (optarg[0] == 's')
 						conf->sep = ';';
-					else if(optarg[0] == 't')
+					else if (optarg[0] == 't')
 						conf->sep = '\t';
-					else if(optarg[0] == 'p')
+					else if (optarg[0] == 'p')
 						conf->sep = ' ';
-					else if(optarg[0] == 'l')
+					else if (optarg[0] == 'l')
 						conf->sep = ':';
 					break;
 			case 'c': /* color rows (thx to <jcorso@cse.Buffalo.EDU>) */
-					if(isdigit(optarg[0])) {
+					if (isdigit(optarg[0])) {
 						conf->clrrow = (char*)malloc(strlen(optarg)+1);
 						strcpy(conf->clrrow, optarg);
 					} else {
@@ -182,8 +182,7 @@ config* parseOptions (config* conf, int argc, char **argv) {
 					}
 					break;
 			case 'r': /* reduce table size (original idea thx to <boaz.gezer@gmail.com>) */
-		
-					if(isdigit(optarg[0])) {
+					if (isdigit(optarg[0])) {
 						tmp = atoi(optarg);
 						conf->red = (tmp>4) ? 4 : (tmp<0) ? 0 : tmp; /* [1-4] */
 					} else {
@@ -208,54 +207,55 @@ config* parseOptions (config* conf, int argc, char **argv) {
 int guessCSV(config* conf, FILE* in) {
 /* guess the block delimiter and the csv separator */
 	int token;
-	
+
 	token = getc(in); /* first char is block delimiter */
-	if(token == EOF) {
+	if (token == EOF) {
 		fprintf(stderr, "ERROR: emtpy file ?\n");
-		return(-1);
+		return -1;
 	} else if (ispunct(token) || token == ' ') {
 	       	/* found first block delimiter, act this way */
 		conf->block = token;
 		fprintf(stderr, "Guessed '%c' as Block Delimiter\n",
 				conf->block);
 		/* stream file while token is printable data */
-		while((token = getc(in)) != conf->block &&
+		while ((token = getc(in)) != conf->block &&
 				token != '\n' &&
 				token != EOF)
 		{/* getc has been done */}
-		if(token == conf->block){
+		if (token == conf->block) {
 			/* second delimiter : next is separator */
 			conf->sep = getc(in);
 			fprintf(stderr, "Guessed '%c' as Separator\n",
 					conf->sep);
-			return(0);
-		}else{
-			return (-1); /* what else ? */
+			return 0;
+		} else {
+			return -1; /* what else ? */
 		}
-	}else{ /* no block delimiter, act this way */
+	} else { /* no block delimiter, act this way */
 		conf->block = 0;
 		fprintf(stderr, "Guessed No Block Delimiter\n");
 		/* stream file while input is not a control char */
-		while(isalnum((token = getc(in))) && 
+		while (!ispunct((token = getc(in))) && 
 				token != '\n' && 
 				token != EOF)
 		{/* getc has been done */}
 		/* guess CSV separator */
-		if(ispunct(token) || token == '\t' || token == ' '){
+		if (ispunct(token) || token == '\t' || token == ' ') {
 			conf->sep = token;
 			fprintf(stderr, "Guessed %c as Separator\n", conf->sep);
-			return(0);
+			return 0;
 		} else { /* did not found any separator */
 			fprintf(stderr, "ERROR: Did not guess any Separator!\n");
-			return(-1);
+			return -1;
 		}
 	}
-	return(0);
+	return 0;
 }
 
 void getMaximums(config* conf, FILE* in)  {
 /* gets the number of cols and chars of a csv file assuming a separator */
 	int token = 0;
+	int nosep = 0;
 	unsigned int curcol = 0;
 	unsigned int curchar = 0;
 	unsigned int inblock = 0;
@@ -266,7 +266,7 @@ void getMaximums(config* conf, FILE* in)  {
 
 	while (token != EOF) {
 		token = getc(in);
-		
+
 		/* EOF ? */
 		if (token == EOF) {
 			continue;
@@ -284,6 +284,14 @@ void getMaximums(config* conf, FILE* in)  {
 			continue;
 		}
 
+		/* check implicit, non-guessed, block */
+		if (token == '\"') {
+			if (nosep == 0)
+				nosep = 1;
+			else 
+				nosep = 0;
+		}
+
 		/* enter/quit a block */
 		if (conf->block && token == conf->block) {
 			inblock = !inblock;
@@ -291,7 +299,7 @@ void getMaximums(config* conf, FILE* in)  {
 		}
 
 		/* count cols in current line */
-		if (token == conf->sep && ((conf->block && !inblock) || !conf->block)) {
+		if (token == conf->sep && ((conf->block && !inblock) || !conf->block) && nosep == 0) {
 			curcol++;
 			continue;
 		}
@@ -329,7 +337,7 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 		token2 = token1;	/* second last character, used for detection of quotation marks */
 		token1 = token;	/* last character, used for detection of quotation marks */
 		token = getc(in);
-		
+
 		/* EOF ? */
 		if (token == EOF) {
 			continue;
@@ -348,13 +356,13 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 			} else { /* first row and repeat and longtable */
 				fprintf(out, "%s\\\\\n", headerrow);
 			}
-			if(conf->hlines) {
+			if (conf->hlines) {
 				fprintf(out, "\\hline\n"); /* TeX draw hline */
 			}
 			if (firstrow && (conf->longtable && conf->repeat)) {
 				fprintf(out, "%s", "\\endhead\n");
 			}
-			if(firstrow && conf->repeat) {
+			if (firstrow && conf->repeat) {
 				char tmp[12];
 				sprintf(tmp, (conf->hlines ? "\\\\\n\\hline" : "\\\\\n"));
 				strcat(headerrow, tmp);
@@ -372,20 +380,20 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 				fprintf(out, "\\end{tabular}\n");
 				fprintf(out, "\\newline\n");
 				fprintf(out, "\\begin{tabular}{");
-				if(conf->vlines) {
+				if (conf->vlines) {
 					putc('|', out);
 				}
-				while(numcols--) {
+				while (numcols--) {
 					putc(conf->pos, out);
-					if(conf->vlines) {
+					if (conf->vlines) {
 						putc('|', out);
 					}
 				}
 				fprintf(out, "}\n");
-				if(conf->hlines) {
+				if (conf->hlines) {
 					fprintf(out, "\\hline\n");
 				}
-				if(conf->repeat && !conf->longtable) {
+				if (conf->repeat && !conf->longtable) {
 					fprintf(out, "%s", headerrow);
 					putc('\n', out);
 				}
@@ -398,19 +406,19 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 
 		/* if commas in cells */
 		/* thx to <florian@heinze.at> */
-		if (token == '\"'){
+		if (token == '\"') {
 			if (nosep == 0)
 				nosep = 1;
 			else 
 				nosep = 0;
 		}
-		
+
 		/* new column ? */
-		if ((token == conf->sep && ((conf->block && !inblock) || !conf->block)) && nosep == 0) {			
+		if ((token == conf->sep && ((conf->block && !inblock) || !conf->block)) && nosep == 0) {
 			if (!(firstrow && (conf->longtable && conf->repeat)))
 				putc(newsep, out);
 			numcols--;
-			if(firstrow && conf->repeat)
+			if (firstrow && conf->repeat)
 			{
 				char tmp[2];
 				tmp[0] = newsep;
@@ -438,7 +446,7 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 						switch (token) {
 							case '\\':
 								fprintf(out, "\\textbackslash{}");
-								if(firstrow && conf->repeat)
+								if (firstrow && conf->repeat)
 								{
 									char tmp[17];
 									sprintf(tmp, "\\textbackslash{}");
@@ -447,7 +455,7 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 								break;
 							default:
 								fprintf(out, "\\%c", token);
-								if(firstrow && conf->repeat)
+								if (firstrow && conf->repeat)
 								{
 									char tmp[3];
 									tmp[0] = '\\';
@@ -464,7 +472,7 @@ void doTeXsub(config* conf, char newsep, FILE* in, FILE* out) {
 			if ((i >= conf->tex->size) || (!conf->escape)) {
 				if (!(firstrow && (conf->longtable && conf->repeat)))
 					putc(token, out); /* do not print the header twice */
-				if(firstrow && conf->repeat)
+				if (firstrow && conf->repeat)
 				{
 					char tmp[2];
 					tmp[0] = token;
@@ -487,49 +495,49 @@ void doTeXdoc(config* conf, FILE* in, FILE* out) {
 	char* tabcolsep[5] = {"0", "0.05", "0.1", "0.2", "0.4"}; /* LaTeX tabcolsep good values */
 
 	numcols = maxcols = conf->cols;
-	if(conf->header){
+	if (conf->header) {
 		fprintf(out, "\\documentclass[a4paper]{article}\n");
 		fprintf(out, "\\usepackage[T1]{fontenc}\n");
-		fprintf(out, "\\usepackage[latin1]{inputenc}\n");
-		if (conf->red){
+		fprintf(out, "\\usepackage[utf8]{inputenc}\n");
+		if (conf->red) {
 			fprintf(out, "\\usepackage{relsize}\n");
 		}
-		if (conf->clrrow){
+		if (conf->clrrow) {
 			fprintf(out, "\\usepackage{colortbl}\n");
 		}
-		if (conf->longtable){
+		if (conf->longtable) {
 			fprintf(out, "\\usepackage{longtable}\n");
 		}
 		fprintf(out, "\\begin{document}\n");
 	}
-	if (conf->clrrow){
+	if (conf->clrrow) {
 		fprintf(out, "\\def\\colorrow{\\rowcolor[gray]{%s}}\n",
 				conf->clrrow);
 	}
-	if (conf->red){
+	if (conf->red) {
 		fprintf(out, "\\relsize{-%s}\n", relsize[conf->red]);
 		fprintf(out, "\\addtolength\\tabcolsep{-%sem}\n", tabcolsep[conf->red]);
 	}
 	if (conf->longtable)
 	{
 	  fprintf(out, "\\begin{longtable}{");
-	  if(conf->vlines)
+	  if (conf->vlines)
 		putc('|', out);
 	}
   	else
 	{
 	  fprintf(out, "\\begin{tabular}{");
-	  if(conf->vlines)
+	  if (conf->vlines)
 		putc('|', out);
 	}
-	while(numcols--)
+	while (numcols--)
 	{
 		fprintf(out, "%c", conf->pos); /* position in cell */
-		if(conf->vlines)
+		if (conf->vlines)
 			putc('|', out);
 	}
 	fprintf(out, "}\n");
-	if(conf->hlines)
+	if (conf->hlines)
 		fprintf(out, "\\hline\n");
 	doTeXsub(conf, '&', in, out); /* & is LaTeX separator */
 	if (conf->longtable) {
@@ -537,11 +545,11 @@ void doTeXdoc(config* conf, FILE* in, FILE* out) {
   	} else {
 	  fprintf(out, "\\end{tabular}\n");
 	}
-	if (conf->red){
+	if (conf->red) {
 		fprintf(out, "\\addtolength\\tabcolsep{+%sem}\n", tabcolsep[conf->red]);
 		fprintf(out, "\\relsize{+%s}\n", relsize[conf->red]);
 	}
-	if(conf->header){
+	if (conf->header) {
 		fprintf(out, "\\end{document}\n");
 	}
 	return;
@@ -571,18 +579,18 @@ int main (int argc, char **argv) {
 	conf->repeat = 0;      /* default; do not repeat the header row */
 	conf->vlines = 1;      /* default; draw lines between columns */
 	conf->hlines = 1;      /* default; draw lines between rows */
-	
+
 	/* TeX charaters to escape */
 	conf->tex = (texcape*)malloc(sizeof(texcape));
 	conf->tex->tab = "\\_#$%^&{}~";
 	conf->tex->size = strlen(conf->tex->tab);
-	
+
 
 	conf = parseOptions(conf, argc, argv);
 
 	if (optind == argc) {
 		/* copy stdin into tmp file */
-		char c;
+		int c;
 		fp = tmpfile();
 		while (EOF != (c = getc(stdin))) {
 			putc(c, fp);
@@ -592,14 +600,15 @@ int main (int argc, char **argv) {
 		fp = fopen(argv[optind], "r");
 	}
 
-	if (!fp){
+	if (!fp) {
 		fprintf(stderr, "Can't open file %s\n", argv[optind]);
 		exit(EXIT_FAILURE);
 	}
 
-	if(conf->guess){
-		if(guessCSV(conf, fp)){
-			fprintf(stderr, "Please run again by using -- delimiter (if any) and --separator\n");
+	if (conf->guess) {
+		if (guessCSV(conf, fp)) {
+			fprintf(stderr, "Please run again by using --delimiter (if any) and --separator\n");
+			fclose(fp);
 			exit(EXIT_FAILURE);
 		}
 		rewind(fp);
@@ -607,9 +616,12 @@ int main (int argc, char **argv) {
 
 	getMaximums(conf, fp);
 	rewind(fp);
+
 	doTeXdoc(conf, fp, stdout);
+
 	free(conf->tex);
-	if (conf->clrrow) free(conf->clrrow); conf->clrrow=NULL;
+	if (conf->clrrow)
+		free(conf->clrrow);
 	free(conf);
 	fclose(fp);
 
